
Installation
************


Stable release
==============

To install glyphtools, run this command in your terminal:

::

   $ pip install glyphtools

This is the preferred method to install glyphtools, as it will always
install the most recent stable release.

If you don’t have `pip <https://pip.pypa.io>`_ installed, this `Python
installation guide
<http://docs.python-guide.org/en/latest/starting/installation/>`_ can
guide you through the process.


From sources
============

The sources for glyphtools can be downloaded from the `Github repo
<https://github.com/simoncozens/glyphtools>`_.

You can either clone the public repository:

::

   $ git clone git://github.com/simoncozens/glyphtools

Or download the `tarball
<https://github.com/simoncozens/glyphtools/tarball/master>`_:

::

   $ curl -OJL https://github.com/simoncozens/glyphtools/tarball/master

Once you have a copy of the source, you can install it with:

::

   $ python setup.py install
